-- Chapter 3

-- Page 106

-- The following is a complete example of the CREATE DATABASE command, specifying three 
-- files and all the properties of each file:

CREATE DATABASE Archive
ON
PRIMARY
( NAME = Arch1,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA \archdat1.mdf',
  SIZE = 100MB,
  MAXSIZE = 200MB,
  FILEGROWTH = 20MB),
( NAME = Arch2,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA \archdat2.ndf',
  SIZE = 10GB,
  MAXSIZE = 50GB,
  FILEGROWTH = 250MB)
LOG ON
( NAME = Archlog1,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA \archlog1.ldf',
  SIZE = 2GB,
  MAXSIZE = 10GB,
  FILEGROWTH = 100MB);

-- Page 112

-- This example creates a database named sales with three filegroups:
 
--    The primary filegroup, with the files salesPrimary1 and salesPrimary2. 
--    The FILEGROWTH increment for both of these files is specified as 100 MB.
 
--    A filegroup named SalesGroup1, with the files salesGrp1File1 and salesGrp1Fi1e2.
 
--    A filegroup named SalesGroup2, with the files salesGrp2File1 and salesGrp2Fi1e2.

CREATE DATABASE Sales
ON PRIMARY
( NAME = salesPrimary1,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\salesPrimary1.mdf',
  SIZE = 1000, MAXSIZE = 5000,
  FILEGROWTH = 1000 ),
( NAME = salesPrimary2,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\salesPrimary2.ndf',
  SIZE = 1000, MAXSIZE = 5000,
  FILEGROWTH = 1000 ),
FILEGROUP SalesGroup1
( NAME = salesGrp1Fi1e1,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\salesGrp1Fi1e1.ndf',
  SIZE = 500, MAXSIZE = 3000,
  FILEGROWTH = 500 ),
( NAME = salesGrp1Fi1e2,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\salesGrp1Fi1e2.ndf',
  SIZE = 500, MAXSIZE = 3000,
  FILEGROWTH = 500 ),
  FILEGROUP SalesGroup2
( NAME = salesGrp2Fi1e1,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\salesGrp2Fi1e1.ndf',
  SIZE = 1000, MAXSIZE = 50000,
  FILEGROWTH = 5000 ),
( NAME = salesGrp2Fi1e2,
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\salesGrp2Fi1e2.ndf',
  SIZE = 1000, MAXSIZE = 50000,
  FILEGROWTH = 500 )
LOG ON
( NAME = 'Sales_log',
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\saleslog.ldf',
  SIZE = 500MB, MAXSIZE = 2500MB,
  FILEGROWTH = 500MB );


-- Page 115

-- The following examples demonstrate some of the changes that you can make using the 
-- ALTER DATABASE command.

-- This example increases the size of a database file:
USE master;
GO
ALTER DATABASE Test1
MODIFY FILE
( NAME = 'test1dat3',
  SIZE = 2000MB);

-- The following example needs three ALTER DATABASE statements to create a new filegroup in a 
-- database, add two 500 MB files to the filegroup, and make the new filegroup the default:
ALTER DATABASE Test1
ADD FILEGROUP Test1FG1;
GO

ALTER DATABASE Test1
ADD FILE
( NAME = 'test1dat4',
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\t1dat4.ndf',
  SIZE = 500MB,
  MAXSIZE = 1000MB,
  FILEGROWTH = 50MB),
( NAME = 'test1dat5',
  FILENAME =
    'C:\Program Files\Microsoft SQL Server\MSSQL11.MSSQLSERVER\MSSQL\DATA\t1dat5.ndf',
  SIZE = 500MB,
  MAXSIZE = 1000MB,
  FILEGROWTH = 50MB)
TO FILEGROUP Test1FG1;
GO

ALTER DATABASE Test1
  MODIFY FILEGROUP Test1FG1 DEFAULT;
GO


-- Page 132

-- The following query shows the mapping of users in the AdventureWorks2012 database to login names, 
-- and it also shows the default schema for each database user. A LEFT JOIN is used because not all 
-- users have corresponding login names.

SELECT s.name as [Login Name], d.name as [User Name],default_schema_name as [Default Schema]
 FROM sys.database_principals d
 LEFT JOIN sys.server_principals s
     ON s.sid = d.sid
 WHERE d.type_description = 'SQL_USER';


